#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
        name='aiospider',
        version='0.0.4.11',
        description='A spider use asyncio.',
        license='MIT License',
        install_requires=['cchardet', 'aiodns', 'aiohttp', 'async-timeout', 'aioredis'],

        author='EINDEX',
        author_email='hi@eindex.me',

        packages=find_packages(),
        platforms='any',
)
